package com.ruoyi.brewery.service;

import java.util.HashMap;
import java.util.List;
import com.ruoyi.brewery.domain.WyActivity;
import com.ruoyi.brewery.domain.WyActivityBar;
import com.ruoyi.brewery.domain.WyActivityFavorite;

/**
 * 营销活动Service接口
 * 
 * @author kxl
 * @date 2024-12-21
 */
public interface IWyActivityService 
{
    /**
     * 查询营销活动
     * 
     * @param id 营销活动主键
     * @return 营销活动
     */
    public WyActivity selectWyActivityById(Long id);

    int updateActivityPopularity(Long activityId);

    /**
     * 查询营销活动列表
     * 
     * @param wyActivity 营销活动
     * @return 营销活动集合
     */
    public List<WyActivity> selectWyActivityList(WyActivity wyActivity);

    List<WyActivity> selectWyActivityListWithData(WyActivity wyActivity);

    HashMap<String, Integer> selectActivityDataByBreweryId(Long breweryId);

    Integer selectActivityCount(WyActivity wyActivity);

    List<WyActivity> selectWyActivityListWithBeer(WyActivity wyActivity);

    List<WyActivity> selectWyActivityListWithBeerAndBar(WyActivity wyActivity, Long barId);

    List<WyActivity> selectFavoritedWyActivityList(WyActivityFavorite wyActivityFavorite);

    /**
     * 新增营销活动
     * 
     * @param wyActivity 营销活动
     * @return 结果
     */
    public int insertWyActivity(WyActivity wyActivity);

    /**
     * 修改营销活动
     * 
     * @param wyActivity 营销活动
     * @return 结果
     */
    public int updateWyActivity(WyActivity wyActivity);

    /**
     * 批量删除营销活动
     * 
     * @param ids 需要删除的营销活动主键集合
     * @return 结果
     */
    public int deleteWyActivityByIds(Long[] ids);

    /**
     * 删除营销活动信息
     * 
     * @param id 营销活动主键
     * @return 结果
     */
    public int deleteWyActivityById(Long id);

    List<WyActivityBar> selectWyActivityBarList(WyActivityBar bar);

    public int insertWyActivityBar(WyActivityBar bar);

    public WyActivityBar selectWyActivityBar(WyActivityBar bar);

    public int deleteWyActivityBarByActivityId(Long activityId);
    public int deleteWyActivityBarByBarId(Long barId);
}
